elephant.cell\_assembly\_detection.cell\_assembly\_detection
============================================================

.. currentmodule:: elephant.cell_assembly_detection

.. autofunction:: cell_assembly_detection